<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that is fired before a mandate is created with GoCardless.
 */
class MandateDetailsEvent extends Event {

  /**
   * The mandate details array built for GoCardless.
   *
   * @var array
   */
  protected $mandate_details;

  /**
   * The Commerce order ID.
   *
   * @var integer
   */
  protected $order_id;

  /**
   * Constructs the object.
   *
   * @param array $mandate_details
   *   The mandate details array to be passed to the GoCardless API.
   * @param integer $order_id
   *   The Commerce order ID.
   */
  public function __construct($mandate_details, $order_id) {
    $this->mandate_details = $mandate_details;
    $this->order_id = $order_id;
  }

  /**
   * Gets the mandate details.
   *
   * @return array
   *   The mandate details array to be passed to the GoCardless API.
   */
  public function getMandateDetails() {
    return $this->mandate_details;
  }

  /**
   * Sets the mandate details.
   *
   * @param array $mandate_details
   *   The mandate details array to be passed to the GoCardless API.
   */
  public function setMandateDetails($mandate_details) {
    $this->mandate_details = $mandate_details;
  }

  /**
   * Gets the order ID.
   *
   * @return integer
   *   The Commerce order ID.
   */
  public function getOrderId() {
    return $this->order_id;
  }
}
