<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that is fired before a payment is created with GoCardless.
 */
class PaymentDetailsEvent extends Event {

  /**
   * The payment details array built for GoCardless.
   *
   * @var array
   */
  protected $payment_details;

  /**
   * The Commerce order item ID.
   *
   * @var integer
   */
  protected $item_id;

  /**
   * The context in which the event was dispatched.
   *
   * @var string
   */
  protected $context;

  /**
   * Constructs the object.
   *
   * @param array $payment_details
   *   The payment details array to be passed to the GoCardless API.
   * @param integer $item_id
   *   The Commerce order item ID.
   * @param string $context
   *   The context in which the event was dispatched.
   */
  public function __construct($payment_details, $item_id, $context) {
    $this->payment_details = $payment_details;
    $this->item_id = $item_id;
    $this->context = $context;
  }

  /**
   * Gets the payment details.
   *
   * @return array
   *   The payment details array to be passed to the GoCardless API.
   */
  public function getPaymentDetails() {
    return $this->payment_details;
  }

  /**
   * Sets the payment details.
   *
   * @param array $payment
   *   The payment details array to be passed to the GoCardless API.
   */
  public function setPaymentDetails($payment_details) {
    $this->payment_details = $payment_details;
  }

  /**
   * Gets the item ID.
   *
   * @return integer
   *   The Commerce order item ID.
   */
  public function getItemId() {
    return $this->item_id;
  }

  /**
   * Gets the Context.
   *
   * @return string
   *   The context in which the event was dispatched.
   */
  public function getContext() {
    return $this->context;
  }
}
