<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that is called before the next payment date is updated.
 */
class PaymentNextEvent extends Event {

  /**
   * The next_payment date as a Unix timestamp.
   *
   * @var integer
   */
  protected $next_payment;

  /**
   * The Commerce order item ID.
   *
   * @var integer
   */
  protected $item_id;


  /**
   * The context in which the event was dispatched.
   *
   * @var string
   */
  protected $context;

  /**
   * Constructs the object.
   *
   * @param integer $next_payment
   *   The next_payment date as a Unix timestamp.
   * @param integer $item_id
   *   The Commerce order item ID.
   * @param string $context
   *   The context in which the event was dispatched.
   */
  public function __construct($next_payment, $item_id, $context) {
    $this->next_payment = $next_payment;
    $this->item_id = $item_id;
    $this->context = $context;
  }

  /**
   * Gets the next payment.
   *
   * @return integer
   *   The next_payment date as a Unix timestamp.
   */
  public function getNextPayment() {
    return $this->next_payment;
  }

  /**
   * Sets the next payment.
   *
   * @param integer $next_payment
   *   The next_payment date as a Unix timestamp.
   */
  public function setNextPayment($next_payment) {
    $this->next_payment = $next_payment;
  }

  /**
   * Gets the item id.
   *
   * @return integer
   *   The commerce order item ID.
   */
  public function getItemID() {
    return $this->item_id;
  }

  /**
   * Gets the Context.
   *
   * @return string
   *   The context in which the event was dispatched.
   */
  public function getContext() {
    return $this->context;
  }
}
