<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that is fired before a subscription is created with GoCardless.
 */
class SubsDetailsEvent extends Event {

  /**
   * The subscription details array built for GoCardless.
   *
   * @var array
   */
  protected $subs_details;

  /**
   * The Commerce order item ID.
   *
   * @var integer
   */
  protected $item_id;

  /**
   * Constructs the object.
   *
   * @param array $subs_details
   *   The subscription details array to be passed to the GoCardless API.
   * @param integer $item_id
   *   The Commerce order item ID.
   */
  public function __construct($subs_details, $item_id) {
    $this->subs_details = $subs_details;
    $this->item_id = $item_id;
  }

  /**
   * Gets the subscription details.
   *
   * @return array
   *   The subscription details array to be passed to the GoCardless API.
   */
  public function getSubsDetails() {
    return $this->subs_details;
  }

  /**
   * Sets the subscription details.
   *
   * @param array $subs_details
   *   The subscription details array to be passed to the GoCardless API.
   */
  public function setSubsDetails($subs_details) {
    $this->subs_details = $subs_details;
  }

  /**
   * Gets the item ID.
   *
   * @return integer
   *   The Commerce order item ID.
   */
  public function getItemId() {
    return $this->item_id;
  }
}
