<?php

/**
 * @file
 * Contains \Drupal\commerce_gc_client\Form\PaymentCancel.
 */

namespace Drupal\commerce_gc_client\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\commerce_order\Entity\Order;
use Drupal\commerce_gc_client\Controller\GoCardlessPartner;

/**
 * Defines a confirmation form for cancelling pending payments.
 */
class PaymentCancel extends ConfirmFormBase {

  /**
   * The commerce order ID of the item to cancel.
   *
   * @var integer
   */
  protected $order_id;

  /**
   * The commerce payment ID of the item to cancel.
   *
   * @var integer
   */
  protected $payment_id;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'commerce_gc_client_payment_cancel';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('Are you sure you want to cancel GoCardless payment @payment_id?', [
      '@payment_id' => $this->payment_id,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('commerce_gc_client.mandate', [
      'commerce_order' => $this->order_id,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('Cancel payment');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return t('Go back');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $order_id = NULL, $payment_id = NULL) {
    $this->order_id = $order_id;
    $this->payment_id = $payment_id;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $order = Order::load($this->order_id);
    $payment_gateway_id = $order->get('payment_gateway')->first()->entity->Id();
    $partner = new GoCardlessPartner($payment_gateway_id);
    $result = $partner->api([
      'endpoint' => 'payments',
      'action' => 'cancel',
      'id' => $this->payment_id,
    ]);
    if ($result->response->status_code == 200) {
      drupal_set_message(t('Payment @payment_id has been cancelled with GoCardless.', ['@payment_id' => $this->payment_id]));
    }
    else {
      drupal_set_message(t('Something went wrong cancelling paynent @payment_id with GoCardless.', ['@payment_id' => $this->payment_id]), 'warning');
    }
    $form_state->setRedirect('commerce_gc_client.mandate', [
      'commerce_order' => $this->order_id,
    ]);
  }
}

